@@ -12,7 +12,7 @@ use Monkey::Patch qw();
 use SHARYANTO::Array::Util qw(match_array_or_regex);
 use SHARYANTO::Package::Util qw(list_package_contents package_exists);
 
-our $VERSION = '0.07'; # VERSION
+our $VERSION = '0.08'; # VERSION
 
 our @EXPORT_OK = qw(patch_package);
 
@@ -102,7 +102,7 @@ sub unimport {
         # do nothing
     } else {
         my $handles = ${"$self\::handles"};
-        #$log->tracef("Unpatching %s ...", [keys %$handles]);
+        $log->tracef("Unpatching %s ...", [keys %$handles]);
         undef ${"$self\::handles"};
         # do we need to undef ${"$self\::config"}?, i'm thinking not really
     }
@@ -123,9 +123,6 @@ sub patch_package {
         croak "FATAL: Target module '$target' not loaded"
             unless package_exists($target);
         my $target_version = ${"$target\::VERSION"};
-        defined($target_version) && length($target_version)
-            or croak "FATAL: Target package '$target' does not have ".
-                "\$VERSION";
         my @target_subs;
         my %tp = list_package_contents($target);
         for (keys %tp) {
@@ -164,26 +161,33 @@ sub patch_package {
                 }
             }
 
-            my $mod_versions = $pspec->{mod_version} // ':all';
-            $mod_versions = ref($mod_versions) eq 'ARRAY' ?
-                [@$mod_versions] : [$mod_versions];
-            for (@$mod_versions) {
-                $_ = qr/.*/    if $_ eq ':all';
-                die "BUG: patch[$i]: unknown tag in mod_version $_"
-                    if /^:/;
-            }
+            unless (!defined($pspec->{mod_version}) ||
+                        $pspec->{mod_version} eq ':all') {
+                defined($target_version) && length($target_version)
+                    or croak "FATAL: Target package '$target' does not have ".
+                        "\$VERSION";
+                my $mod_versions = $pspec->{mod_version};
+                $mod_versions = ref($mod_versions) eq 'ARRAY' ?
+                    [@$mod_versions] : [$mod_versions];
+                for (@$mod_versions) {
+                    $_ = qr/.*/    if $_ eq ':all';
+                    die "BUG: patch[$i]: unknown tag in mod_version $_"
+                        if /^:/;
+                }
 
-            my $ver_match=match_array_or_regex($target_version, $mod_versions);
-            unless ($ver_match) {
-                carp "patch[$i]: Target module version $target_version ".
-                    "does not match [".join(", ", @$mod_versions)."], ".
-                        ($opts->{force} ? "patching anyway (force)":"skipped").
-                            ".";
-                next PATCH unless $opts->{force};
+                my $ver_match=match_array_or_regex(
+                    $target_version, $mod_versions);
+                unless ($ver_match) {
+                    carp "patch[$i]: Target module version $target_version ".
+                        "does not match [".join(", ", @$mod_versions)."], ".
+                            ($opts->{force} ?
+                                 "patching anyway (force)":"skipped"). ".";
+                    next PATCH unless $opts->{force};
+                }
             }
 
             for my $s (@s) {
-                #$log->tracef("Patching %s ...", $s);
+                $log->tracef("Patching %s ...", $s);
                 my $ctx = {
                     orig_name => "$target\::$s",
                 };
@@ -212,7 +216,7 @@ Module::Patch - Patch package with a set of patches
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
